opentelemetry_honeycomb v0.3.0-rc.0 OpenTelemetry.Honeycomb.Http.WriteKeyMissingBackend
A no-op HTTP back end.
Installed instead of your configured back end if write_key is nil.
A no-op HTTP back end.
Installed instead of your configured back end if write_key is nil.